# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InsightsApiModelsResponsesMiscTemperatureData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'measurement_date': 'date',
        'publish_time': 'datetime',
        'temperature': 'float',
        'temperature_reference_average': 'float',
        'temperature_reference_high': 'float',
        'temperature_reference_low': 'float'
    }

    attribute_map = {
        'measurement_date': 'measurementDate',
        'publish_time': 'publishTime',
        'temperature': 'temperature',
        'temperature_reference_average': 'temperatureReferenceAverage',
        'temperature_reference_high': 'temperatureReferenceHigh',
        'temperature_reference_low': 'temperatureReferenceLow'
    }

    def __init__(self, measurement_date=None, publish_time=None, temperature=None, temperature_reference_average=None, temperature_reference_high=None, temperature_reference_low=None):  # noqa: E501
        """InsightsApiModelsResponsesMiscTemperatureData - a model defined in Swagger"""  # noqa: E501
        self._measurement_date = None
        self._publish_time = None
        self._temperature = None
        self._temperature_reference_average = None
        self._temperature_reference_high = None
        self._temperature_reference_low = None
        self.discriminator = None
        if measurement_date is not None:
            self.measurement_date = measurement_date
        if publish_time is not None:
            self.publish_time = publish_time
        if temperature is not None:
            self.temperature = temperature
        if temperature_reference_average is not None:
            self.temperature_reference_average = temperature_reference_average
        if temperature_reference_high is not None:
            self.temperature_reference_high = temperature_reference_high
        if temperature_reference_low is not None:
            self.temperature_reference_low = temperature_reference_low

    @property
    def measurement_date(self):
        """Gets the measurement_date of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501


        :return: The measurement_date of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501
        :rtype: date
        """
        return self._measurement_date

    @measurement_date.setter
    def measurement_date(self, measurement_date):
        """Sets the measurement_date of this InsightsApiModelsResponsesMiscTemperatureData.


        :param measurement_date: The measurement_date of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501
        :type: date
        """

        self._measurement_date = measurement_date

    @property
    def publish_time(self):
        """Gets the publish_time of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501


        :return: The publish_time of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501
        :rtype: datetime
        """
        return self._publish_time

    @publish_time.setter
    def publish_time(self, publish_time):
        """Sets the publish_time of this InsightsApiModelsResponsesMiscTemperatureData.


        :param publish_time: The publish_time of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501
        :type: datetime
        """

        self._publish_time = publish_time

    @property
    def temperature(self):
        """Gets the temperature of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501


        :return: The temperature of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501
        :rtype: float
        """
        return self._temperature

    @temperature.setter
    def temperature(self, temperature):
        """Sets the temperature of this InsightsApiModelsResponsesMiscTemperatureData.


        :param temperature: The temperature of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501
        :type: float
        """

        self._temperature = temperature

    @property
    def temperature_reference_average(self):
        """Gets the temperature_reference_average of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501


        :return: The temperature_reference_average of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501
        :rtype: float
        """
        return self._temperature_reference_average

    @temperature_reference_average.setter
    def temperature_reference_average(self, temperature_reference_average):
        """Sets the temperature_reference_average of this InsightsApiModelsResponsesMiscTemperatureData.


        :param temperature_reference_average: The temperature_reference_average of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501
        :type: float
        """

        self._temperature_reference_average = temperature_reference_average

    @property
    def temperature_reference_high(self):
        """Gets the temperature_reference_high of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501


        :return: The temperature_reference_high of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501
        :rtype: float
        """
        return self._temperature_reference_high

    @temperature_reference_high.setter
    def temperature_reference_high(self, temperature_reference_high):
        """Sets the temperature_reference_high of this InsightsApiModelsResponsesMiscTemperatureData.


        :param temperature_reference_high: The temperature_reference_high of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501
        :type: float
        """

        self._temperature_reference_high = temperature_reference_high

    @property
    def temperature_reference_low(self):
        """Gets the temperature_reference_low of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501


        :return: The temperature_reference_low of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501
        :rtype: float
        """
        return self._temperature_reference_low

    @temperature_reference_low.setter
    def temperature_reference_low(self, temperature_reference_low):
        """Sets the temperature_reference_low of this InsightsApiModelsResponsesMiscTemperatureData.


        :param temperature_reference_low: The temperature_reference_low of this InsightsApiModelsResponsesMiscTemperatureData.  # noqa: E501
        :type: float
        """

        self._temperature_reference_low = temperature_reference_low

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InsightsApiModelsResponsesMiscTemperatureData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InsightsApiModelsResponsesMiscTemperatureData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
