# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import elexonpy
from elexonpy.api.balancing_services_adjustment___net_api import BalancingServicesAdjustmentNetApi  # noqa: E501
from elexonpy.rest import ApiException


class TestBalancingServicesAdjustmentNetApi(unittest.TestCase):
    """BalancingServicesAdjustmentNetApi unit test stubs"""

    def setUp(self):
        self.api = BalancingServicesAdjustmentNetApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_balancing_nonbm_netbsad_events_get(self):
        """Test case for balancing_nonbm_netbsad_events_get

        Net balancing services adjustment events (NETBSAD)  # noqa: E501
        """
        pass

    def test_balancing_nonbm_netbsad_get(self):
        """Test case for balancing_nonbm_netbsad_get

        Net balancing services adjustment time series (NETBSAD)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
