# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InsightsApiModelsResponsesBalancingDynamicRateData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dataset': 'str',
        'settlement_date': 'date',
        'settlement_period': 'int',
        'time': 'datetime',
        'rate1': 'float',
        'elbow2': 'float',
        'rate2': 'float',
        'elbow3': 'float',
        'rate3': 'float',
        'national_grid_bm_unit': 'str',
        'bm_unit': 'str'
    }

    attribute_map = {
        'dataset': 'dataset',
        'settlement_date': 'settlementDate',
        'settlement_period': 'settlementPeriod',
        'time': 'time',
        'rate1': 'rate1',
        'elbow2': 'elbow2',
        'rate2': 'rate2',
        'elbow3': 'elbow3',
        'rate3': 'rate3',
        'national_grid_bm_unit': 'nationalGridBmUnit',
        'bm_unit': 'bmUnit'
    }

    def __init__(self, dataset=None, settlement_date=None, settlement_period=None, time=None, rate1=None, elbow2=None, rate2=None, elbow3=None, rate3=None, national_grid_bm_unit=None, bm_unit=None):  # noqa: E501
        """InsightsApiModelsResponsesBalancingDynamicRateData - a model defined in Swagger"""  # noqa: E501
        self._dataset = None
        self._settlement_date = None
        self._settlement_period = None
        self._time = None
        self._rate1 = None
        self._elbow2 = None
        self._rate2 = None
        self._elbow3 = None
        self._rate3 = None
        self._national_grid_bm_unit = None
        self._bm_unit = None
        self.discriminator = None
        if dataset is not None:
            self.dataset = dataset
        if settlement_date is not None:
            self.settlement_date = settlement_date
        if settlement_period is not None:
            self.settlement_period = settlement_period
        if time is not None:
            self.time = time
        if rate1 is not None:
            self.rate1 = rate1
        if elbow2 is not None:
            self.elbow2 = elbow2
        if rate2 is not None:
            self.rate2 = rate2
        if elbow3 is not None:
            self.elbow3 = elbow3
        if rate3 is not None:
            self.rate3 = rate3
        if national_grid_bm_unit is not None:
            self.national_grid_bm_unit = national_grid_bm_unit
        if bm_unit is not None:
            self.bm_unit = bm_unit

    @property
    def dataset(self):
        """Gets the dataset of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501


        :return: The dataset of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501
        :rtype: str
        """
        return self._dataset

    @dataset.setter
    def dataset(self, dataset):
        """Sets the dataset of this InsightsApiModelsResponsesBalancingDynamicRateData.


        :param dataset: The dataset of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501
        :type: str
        """

        self._dataset = dataset

    @property
    def settlement_date(self):
        """Gets the settlement_date of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501


        :return: The settlement_date of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501
        :rtype: date
        """
        return self._settlement_date

    @settlement_date.setter
    def settlement_date(self, settlement_date):
        """Sets the settlement_date of this InsightsApiModelsResponsesBalancingDynamicRateData.


        :param settlement_date: The settlement_date of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501
        :type: date
        """

        self._settlement_date = settlement_date

    @property
    def settlement_period(self):
        """Gets the settlement_period of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501


        :return: The settlement_period of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501
        :rtype: int
        """
        return self._settlement_period

    @settlement_period.setter
    def settlement_period(self, settlement_period):
        """Sets the settlement_period of this InsightsApiModelsResponsesBalancingDynamicRateData.


        :param settlement_period: The settlement_period of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501
        :type: int
        """

        self._settlement_period = settlement_period

    @property
    def time(self):
        """Gets the time of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501


        :return: The time of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501
        :rtype: datetime
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this InsightsApiModelsResponsesBalancingDynamicRateData.


        :param time: The time of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501
        :type: datetime
        """

        self._time = time

    @property
    def rate1(self):
        """Gets the rate1 of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501


        :return: The rate1 of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501
        :rtype: float
        """
        return self._rate1

    @rate1.setter
    def rate1(self, rate1):
        """Sets the rate1 of this InsightsApiModelsResponsesBalancingDynamicRateData.


        :param rate1: The rate1 of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501
        :type: float
        """

        self._rate1 = rate1

    @property
    def elbow2(self):
        """Gets the elbow2 of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501


        :return: The elbow2 of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501
        :rtype: float
        """
        return self._elbow2

    @elbow2.setter
    def elbow2(self, elbow2):
        """Sets the elbow2 of this InsightsApiModelsResponsesBalancingDynamicRateData.


        :param elbow2: The elbow2 of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501
        :type: float
        """

        self._elbow2 = elbow2

    @property
    def rate2(self):
        """Gets the rate2 of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501


        :return: The rate2 of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501
        :rtype: float
        """
        return self._rate2

    @rate2.setter
    def rate2(self, rate2):
        """Sets the rate2 of this InsightsApiModelsResponsesBalancingDynamicRateData.


        :param rate2: The rate2 of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501
        :type: float
        """

        self._rate2 = rate2

    @property
    def elbow3(self):
        """Gets the elbow3 of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501


        :return: The elbow3 of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501
        :rtype: float
        """
        return self._elbow3

    @elbow3.setter
    def elbow3(self, elbow3):
        """Sets the elbow3 of this InsightsApiModelsResponsesBalancingDynamicRateData.


        :param elbow3: The elbow3 of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501
        :type: float
        """

        self._elbow3 = elbow3

    @property
    def rate3(self):
        """Gets the rate3 of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501


        :return: The rate3 of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501
        :rtype: float
        """
        return self._rate3

    @rate3.setter
    def rate3(self, rate3):
        """Sets the rate3 of this InsightsApiModelsResponsesBalancingDynamicRateData.


        :param rate3: The rate3 of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501
        :type: float
        """

        self._rate3 = rate3

    @property
    def national_grid_bm_unit(self):
        """Gets the national_grid_bm_unit of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501


        :return: The national_grid_bm_unit of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501
        :rtype: str
        """
        return self._national_grid_bm_unit

    @national_grid_bm_unit.setter
    def national_grid_bm_unit(self, national_grid_bm_unit):
        """Sets the national_grid_bm_unit of this InsightsApiModelsResponsesBalancingDynamicRateData.


        :param national_grid_bm_unit: The national_grid_bm_unit of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501
        :type: str
        """

        self._national_grid_bm_unit = national_grid_bm_unit

    @property
    def bm_unit(self):
        """Gets the bm_unit of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501


        :return: The bm_unit of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501
        :rtype: str
        """
        return self._bm_unit

    @bm_unit.setter
    def bm_unit(self, bm_unit):
        """Sets the bm_unit of this InsightsApiModelsResponsesBalancingDynamicRateData.


        :param bm_unit: The bm_unit of this InsightsApiModelsResponsesBalancingDynamicRateData.  # noqa: E501
        :type: str
        """

        self._bm_unit = bm_unit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InsightsApiModelsResponsesBalancingDynamicRateData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InsightsApiModelsResponsesBalancingDynamicRateData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
