# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import elexonpy
from elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_transparency_remit_remit_message_identifier_with_url import InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl  # noqa: E501
from elexonpy.rest import ApiException


class TestInsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl(unittest.TestCase):
    """InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testInsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl(self):
        """Test InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl"""
        # FIXME: construct object with mandatory attributes with example values
        # model = elexonpy.models.insights_api_models_responses_response_with_metadata1_insights_api_models_responses_transparency_remit_remit_message_identifier_with_url.InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
