# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import elexonpy
from elexonpy.api.indicated_forecast_api import IndicatedForecastApi  # noqa: E501
from elexonpy.rest import ApiException


class TestIndicatedForecastApi(unittest.TestCase):
    """IndicatedForecastApi unit test stubs"""

    def setUp(self):
        self.api = IndicatedForecastApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_forecast_indicated_day_ahead_evolution_get(self):
        """Test case for forecast_indicated_day_ahead_evolution_get

        Evolution indicated day-ahead forecast (INDDEM, INDGEN, IMBALNGC, MELNGC)  # noqa: E501
        """
        pass

    def test_forecast_indicated_day_ahead_get(self):
        """Test case for forecast_indicated_day_ahead_get

        Latest indicated day-ahead forecast (INDDEM, INDGEN, IMBALNGC, MELNGC)  # noqa: E501
        """
        pass

    def test_forecast_indicated_day_ahead_history_get(self):
        """Test case for forecast_indicated_day_ahead_history_get

        Historical indicated day-ahead forecast (INDDEM, INDGEN, IMBALNGC, MELNGC)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
