# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import elexonpy
from elexonpy.api.remit_api import REMITApi  # noqa: E501
from elexonpy.rest import ApiException


class TestREMITApi(unittest.TestCase):
    """REMITApi unit test stubs"""

    def setUp(self):
        self.api = REMITApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_remit_get(self):
        """Test case for remit_get

        Bulk fetch message details by IDs  # noqa: E501
        """
        pass

    def test_remit_list_by_event_get(self):
        """Test case for remit_list_by_event_get

        List messages by event time  # noqa: E501
        """
        pass

    def test_remit_list_by_event_stream_get(self):
        """Test case for remit_list_by_event_stream_get

        List messages by event time (stream)  # noqa: E501
        """
        pass

    def test_remit_list_by_publish_get(self):
        """Test case for remit_list_by_publish_get

        List messages by publish time  # noqa: E501
        """
        pass

    def test_remit_list_by_publish_stream_get(self):
        """Test case for remit_list_by_publish_stream_get

        List messages by publish time (stream)  # noqa: E501
        """
        pass

    def test_remit_message_id_get(self):
        """Test case for remit_message_id_get

        Fetch message details by ID  # noqa: E501
        """
        pass

    def test_remit_revisions_get(self):
        """Test case for remit_revisions_get

        List all message revisions  # noqa: E501
        """
        pass

    def test_remit_search_get(self):
        """Test case for remit_search_get

        Fetch message details by mRID  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
