# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import elexonpy
from elexonpy.api.system_api import SystemApi  # noqa: E501
from elexonpy.rest import ApiException


class TestSystemApi(unittest.TestCase):
    """SystemApi unit test stubs"""

    def setUp(self):
        self.api = SystemApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_system_demand_control_instructions_get(self):
        """Test case for system_demand_control_instructions_get

        Demand control instructions (DCI)  # noqa: E501
        """
        pass

    def test_system_frequency_get(self):
        """Test case for system_frequency_get

        System frequency (FREQ)  # noqa: E501
        """
        pass

    def test_system_frequency_stream_get(self):
        """Test case for system_frequency_stream_get

        System frequency (FREQ) stream  # noqa: E501
        """
        pass

    def test_system_warnings_get(self):
        """Test case for system_warnings_get

        System warnings (SYSWARN)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
