# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import elexonpy
from elexonpy.api.generation_api import GenerationApi  # noqa: E501
from elexonpy.rest import ApiException


class TestGenerationApi(unittest.TestCase):
    """GenerationApi unit test stubs"""

    def setUp(self):
        self.api = GenerationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_generation_actual_per_type_day_total_get(self):
        """Test case for generation_actual_per_type_day_total_get

        Current snapshot of actual generation by fuel type categories (AGPT/B1620)  # noqa: E501
        """
        pass

    def test_generation_actual_per_type_get(self):
        """Test case for generation_actual_per_type_get

        Historic actual generation automatically down-sampled (AGPT/B1620)  # noqa: E501
        """
        pass

    def test_generation_actual_per_type_wind_and_solar_get(self):
        """Test case for generation_actual_per_type_wind_and_solar_get

        Historic actual or estimated wind and solar power generation (AGWS/B1630)  # noqa: E501
        """
        pass

    def test_generation_outturn_current_get(self):
        """Test case for generation_outturn_current_get

        Current snapshot of generation by fuel type categories (FUELINST, FUELHH)  # noqa: E501
        """
        pass

    def test_generation_outturn_fuelinsthhcur_get(self):
        """Test case for generation_outturn_fuelinsthhcur_get

        This endpoint is obsolete, and this location may be removed with no further notice.   # noqa: E501
        """
        pass

    def test_generation_outturn_get(self):
        """Test case for generation_outturn_get

        Total generation outturn (FUELINST)  # noqa: E501
        """
        pass

    def test_generation_outturn_half_hourly_interconnector_get(self):
        """Test case for generation_outturn_half_hourly_interconnector_get

        This endpoint is obsolete, and this location may be removed with no further notice.   # noqa: E501
        """
        pass

    def test_generation_outturn_interconnectors_get(self):
        """Test case for generation_outturn_interconnectors_get

        Historic half-hourly interconnector flows (FUELINST)  # noqa: E501
        """
        pass

    def test_generation_outturn_summary_get(self):
        """Test case for generation_outturn_summary_get

        Historic generation automatically down-sampled (FUELINST)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
